@@ -4,13 +4,15 @@
 import math
 import numpy as np
 from copy import deepcopy
-from sklearn.base import BaseEstimator
+from sklearn.base import BaseEstimator, ClassifierMixin, RegressorMixin
+from sklearn.utils.multiclass import check_classification_targets
+from sklearn.utils.validation import check_X_y, check_array, check_is_fitted
 
 from imodels.rule_list.rule_list import RuleList
 
 
-class GreedyRuleListClassifier(BaseEstimator, RuleList):
-    def __init__(self, max_depth: int=5, class_weight=None, criterion: str='gini', strategy: str='max'):
+class GreedyRuleListClassifier(BaseEstimator, RuleList, ClassifierMixin):
+    def __init__(self, max_depth: int = 5, class_weight=None, criterion: str = 'gini', strategy: str = 'max'):
         '''
         Params
         ------
@@ -23,15 +25,14 @@ class GreedyRuleListClassifier(BaseEstimator, RuleList):
             How to select which side of split becomes leaf node
             Currently only supports 'max' - (higher risk side of split becomes leaf node)
         '''
-        
+
         self.max_depth = max_depth
-        self.feature_names = None
         self.class_weight = class_weight
         self.criterion = criterion
         self.strategy = strategy
-        self.depth = 0 # tracks the fitted depth
+        self.depth = 0  # tracks the fitted depth
 
-    def fit(self, x, y, depth: int=0, feature_names=None, verbose=False):
+    def fit(self, x, y, depth: int = 0, feature_names=None, verbose=False):
         """
         Params
         ------
@@ -45,17 +46,12 @@ class GreedyRuleListClassifier(BaseEstimator, RuleList):
 
         # set self.feature_names and make sure x, y are not pandas type
         if 'pandas' in str(type(x)):
-            self.feature_names = x.columns
             x = x.values
         else:
-            if self.feature_names is None:
-                self.feature_names = ['feat ' + str(i) for i in range(x.shape[1])]
+            if feature_names is None:
+                self.feature_names_ = ['feat ' + str(i) for i in range(x.shape[1])]
         if feature_names is not None:
-            self.feature_names = feature_names
-        if 'pandas' in str(type(y)):
-            y = y.values
-        assert type(x) == np.ndarray, 'x is not numpy array'
-        assert type(y) == np.ndarray, 'y is not numpy array'
+            self.feature_names_ = feature_names
 
         # base case 1: no data in this group
         if len(y) == 0:
@@ -79,7 +75,7 @@ class GreedyRuleListClassifier(BaseEstimator, RuleList):
             if self.strategy == 'max':
                 y_left = y[x[:, col] < cutoff]  # left-hand side data
                 y_right = y[x[:, col] >= cutoff]  # right-hand side data
-                if np.mean(y_left) > np.mean(y_right):
+                if len(y_left) > 0 and np.mean(y_left) > np.mean(y_right):
                     flip = True
                     tmp = deepcopy(y_left)
                     y_left = deepcopy(y_right)
@@ -90,16 +86,15 @@ class GreedyRuleListClassifier(BaseEstimator, RuleList):
                     x_left = x[x[:, col] < cutoff]
             else:
                 print('strategy must be max!')
-                
-                
+
             # print
             if verbose:
                 print(
-                    f'{np.mean(100 * y):.2f} -> {self.feature_names[col]} -> {np.mean(100 * y_left):.2f} ({y_left.size}) {np.mean(100 * y_right):.2f} ({y_right.size})')
+                    f'{np.mean(100 * y):.2f} -> {self.feature_names_[col]} -> {np.mean(100 * y_left):.2f} ({y_left.size}) {np.mean(100 * y_right):.2f} ({y_right.size})')
 
             # save info
             par_node = [{
-                'col': self.feature_names[col],
+                'col': self.feature_names_[col],
                 'index_col': col,
                 'cutoff': cutoff,
                 'val': np.mean(y),  # values before splitting
@@ -114,11 +109,12 @@ class GreedyRuleListClassifier(BaseEstimator, RuleList):
 
             self.depth += 1  # increase the depth since we call fit once
             self.rules_ = par_node
+            self.complexity_ = len(self.rules_)
             return par_node
 
     def predict_proba(self, X):
-        if 'pandas' in str(type(X)):
-            X = X.values
+        check_is_fitted(self)
+        X = check_array(X)
         n = X.shape[0]
         probs = np.zeros(n)
         for i in range(n):
@@ -132,6 +128,8 @@ class GreedyRuleListClassifier(BaseEstimator, RuleList):
         return np.vstack((1 - probs, probs)).transpose()  # probs (n, 2)
 
     def predict(self, X):
+        check_is_fitted(self)
+        X = check_array(X)
         return np.argmax(self.predict_proba(X), axis=1)
 
     def __str__(self):
@@ -291,7 +289,6 @@ class GreedyRuleListClassifier(BaseEstimator, RuleList):
             # weights for each class
             weight = sum(y == c) / n
 
-            
             def entropy_from_counts(c1, c2):
                 """Returns entropy of a group of data
                 c1: count of one class
@@ -305,7 +302,7 @@ class GreedyRuleListClassifier(BaseEstimator, RuleList):
                 p1 = c1 * 1.0 / (c1 + c2)
                 p2 = c2 * 1.0 / (c1 + c2)
                 return entropy_func(p1) + entropy_func(p2)
-            
+
             # weighted avg
             s += weight * entropy_from_counts(sum(y == c), sum(y != c))
         return s
