@@ -1,8 +1,7 @@
-from typing import Tuple, List, Dict
-
 import numpy as np
 import pandas as pd
 from sklearn.utils.validation import check_array, check_is_fitted
+from typing import Tuple, List, Dict
 
 
 class RuleSet:
@@ -34,3 +33,9 @@ class RuleSet:
             scores[list(df.query(r).index)] += w[0]
 
         return scores
+
+    def _get_complexity(self):
+        check_is_fitted(self, ['rules_without_feature_names_'])
+        num_rules = len(self.rules_without_feature_names_)
+        extra_antecedents = np.sum([(len(rule.agg_dict) - 1) for rule in self.rules_without_feature_names_])
+        return num_rules + extra_antecedents * 0.5
