@@ -3,7 +3,6 @@ from urllib.request import urlretrieve
 
 import numpy as np
 from scipy.io.arff import loadarff
-from sklearn.datasets import fetch_openml
 from sklearn.model_selection import train_test_split
 
 from imodels.rule_list.bayesian_rule_list.bayesian_rule_list import BayesianRuleListClassifier
@@ -15,19 +14,19 @@ class TestBRL(unittest.TestCase):
     def test_integration_stability(self):
         '''Test on synthetic dataset
         '''
-        X = [[0, 0, 1, 1, 0],
-             [1, 0, 0, 0, 0],
-             [0, 0, 1, 0, 0],
-             [1, 0, 0, 0, 0],
-             [1, 1, 0, 1, 1],
-             [1, 1, 1, 1, 1],
-             [0, 1, 1, 1, 1],
-             [1, 0, 1, 1, 1]]
-        y = [0, 0, 0, 0, 1, 1, 1, 1]
+        X = np.array([[0, 0, 1, 1, 0],
+                     [1, 0, 0, 0, 0],
+                     [0, 0, 1, 0, 0],
+                     [1, 0, 0, 0, 0],
+                     [1, 1, 0, 1, 1],
+                     [1, 1, 1, 1, 1],
+                     [0, 1, 1, 1, 1],
+                     [1, 0, 1, 1, 1]])
+        y = np.array([0, 0, 0, 0, 1, 1, 1, 1])
         M = BayesianRuleListClassifier(minsupport=0.02)
         feat = ['ft1', 'ft2', 'ft3', 'ft4', 'ft5']
         M.fit(X, y, feature_labels=feat)
-        assert [M.predict([row], threshold=0.5) for row in X] == y
+        assert (np.array([M.predict(np.array([row]), threshold=0.5) for row in X]).flatten() == y).all()
 
     def test_integration_fitting(self):
         '''Test on a real (small) dataset
@@ -41,7 +40,7 @@ class TestBRL(unittest.TestCase):
         data = loadarff(os.path.join(path_to_tests, "test_data/diabetes.arff"))
         data_np = np.array(list(map(lambda x: np.array(list(x)), data[0])))
         X, y_text = data_np[:, :-1].astype('float32'), data_np[:, -1].astype('str')
-        y = (y_text == 'tested_positive').astype(np.int)  # labels 0-1
+        y = (y_text == 'tested_positive').astype(int)  # labels 0-1
 
         X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.75)  # split
 
